@@ -1,15 +1,19 @@
 # pylint: skip-file
 from . import exceptions
+from .jsonwebkeyset import JSONWebKeySet
 from .jsonwebtoken import JSONWebToken
 from .keychain import keychain
 from .keychain import Keychain
+from . import loaders
 from . import model
 
 
 __all__ = [
     'exceptions',
     'keychain',
+    'loaders',
     'model',
+    'JSONWebKeySet',
     'JSONWebToken',
     'Keychain',
 ]
